==> cdk-cx-api-0.26.0-sources.jar: software/amazon/awscdk/cxapi/BuildStep.java <==
package software.amazon.awscdk.cxapi;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T12:52:17.978Z")
public interface BuildStep extends software.amazon.jsii.JsiiSerializable {
    java.util.Map<java.lang.String, java.lang.Object> getParameters();
    void setParameters(final java.util.Map<java.lang.String, java.lang.Object> value);
    java.lang.String getType();
    void setType(final java.lang.String value);
    java.util.List<java.lang.String> getDepends();
    void setDepends(final java.util.List<java.lang.String> value);

    /**
     * @return a {@link Builder} of {@link BuildStep}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link BuildStep}
     */
    final class Builder {
        private java.util.Map<java.lang.String, java.lang.Object> _parameters;
        private java.lang.String _type;
        @javax.annotation.Nullable
        private java.util.List<java.lang.String> _depends;

        /**
         * Sets the value of Parameters
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withParameters(final java.util.Map<java.lang.String, java.lang.Object> value) {
            this._parameters = java.util.Objects.requireNonNull(value, "parameters is required");
            return this;
        }
        /**
         * Sets the value of Type
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withType(final java.lang.String value) {
            this._type = java.util.Objects.requireNonNull(value, "type is required");
            return this;
        }
        /**
         * Sets the value of Depends
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withDepends(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
            this._depends = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BuildStep}
         * @throws NullPointerException if any required attribute was not provided
         */
        public BuildStep build() {
            return new BuildStep() {
                private java.util.Map<java.lang.String, java.lang.Object> $parameters = java.util.Objects.requireNonNull(_parameters, "parameters is required");
                private java.lang.String $type = java.util.Objects.requireNonNull(_type, "type is required");
                @javax.annotation.Nullable
                private java.util.List<java.lang.String> $depends = _depends;

                @Override
                public java.util.Map<java.lang.String, java.lang.Object> getParameters() {
                    return this.$parameters;
                }

                @Override
                public void setParameters(final java.util.Map<java.lang.String, java.lang.Object> value) {
                    this.$parameters = java.util.Objects.requireNonNull(value, "parameters is required");
                }

                @Override
                public java.lang.String getType() {
                    return this.$type;
                }

                @Override
                public void setType(final java.lang.String value) {
                    this.$type = java.util.Objects.requireNonNull(value, "type is required");
                }

                @Override
                public java.util.List<java.lang.String> getDepends() {
                    return this.$depends;
                }

                @Override
                public void setDepends(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
                    this.$depends = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.cxapi.BuildStep {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        @Override
        public java.util.Map<java.lang.String, java.lang.Object> getParameters() {
            return this.jsiiGet("parameters", java.util.Map.class);
        }

        @Override
        public void setParameters(final java.util.Map<java.lang.String, java.lang.Object> value) {
            this.jsiiSet("parameters", java.util.Objects.requireNonNull(value, "parameters is required"));
        }

        @Override
        public java.lang.String getType() {
            return this.jsiiGet("type", java.lang.String.class);
        }

        @Override
        public void setType(final java.lang.String value) {
            this.jsiiSet("type", java.util.Objects.requireNonNull(value, "type is required"));
        }

        @Override
        @javax.annotation.Nullable
        public java.util.List<java.lang.String> getDepends() {
            return this.jsiiGet("depends", java.util.List.class);
        }

        @Override
        public void setDepends(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
            this.jsiiSet("depends", value);
        }
    }
}

==> cdk-cx-api-0.27.0-sources.jar: software/amazon/awscdk/cxapi/BuildStep.java <==
package software.amazon.awscdk.cxapi;

@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-03-28T21:30:07.022Z")
public interface BuildStep extends software.amazon.jsii.JsiiSerializable {
    java.util.Map<java.lang.String, java.lang.Object> getParameters();
    java.lang.String getType();
    java.util.List<java.lang.String> getDepends();

    /**
     * @return a {@link Builder} of {@link BuildStep}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link BuildStep}
     */
    final class Builder {
        private java.util.Map<java.lang.String, java.lang.Object> _parameters;
        private java.lang.String _type;
        @javax.annotation.Nullable
        private java.util.List<java.lang.String> _depends;

        /**
         * Sets the value of Parameters
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withParameters(final java.util.Map<java.lang.String, java.lang.Object> value) {
            this._parameters = java.util.Objects.requireNonNull(value, "parameters is required");
            return this;
        }
        /**
         * Sets the value of Type
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withType(final java.lang.String value) {
            this._type = java.util.Objects.requireNonNull(value, "type is required");
            return this;
        }
        /**
         * Sets the value of Depends
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withDepends(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
            this._depends = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BuildStep}
         * @throws NullPointerException if any required attribute was not provided
         */
        public BuildStep build() {
            return new BuildStep() {
                private final java.util.Map<java.lang.String, java.lang.Object> $parameters = java.util.Objects.requireNonNull(_parameters, "parameters is required");
                private final java.lang.String $type = java.util.Objects.requireNonNull(_type, "type is required");
                @javax.annotation.Nullable
                private final java.util.List<java.lang.String> $depends = _depends;

                @Override
                public java.util.Map<java.lang.String, java.lang.Object> getParameters() {
                    return this.$parameters;
                }

                @Override
                public java.lang.String getType() {
                    return this.$type;
                }

                @Override
                public java.util.List<java.lang.String> getDepends() {
                    return this.$depends;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("parameters", om.valueToTree(this.getParameters()));
                    obj.set("type", om.valueToTree(this.getType()));
                    obj.set("depends", om.valueToTree(this.getDepends()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.cxapi.BuildStep {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        @Override
        public java.util.Map<java.lang.String, java.lang.Object> getParameters() {
            return this.jsiiGet("parameters", java.util.Map.class);
        }

        @Override
        public java.lang.String getType() {
            return this.jsiiGet("type", java.lang.String.class);
        }

        @Override
        @javax.annotation.Nullable
        public java.util.List<java.lang.String> getDepends() {
            return this.jsiiGet("depends", java.util.List.class);
        }
    }
}
